==> fhevmjs-0.0.1.tgz: package/lib/node.js <==
'use strict';

var nodeTfhe = require('node-tfhe');
var sodium = require('libsodium-wrappers');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */


function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var encrypt8 = function (value, publicKey) {
    var uint8Array = new Uint8Array([value]);
    var encrypted = nodeTfhe.CompactFheUint8List.encrypt_with_compact_public_key(uint8Array, publicKey);
    return encrypted.serialize();
};
var encrypt16 = function (value, publicKey) {
    var uint16Array = new Uint16Array([value]);
    var encrypted = nodeTfhe.CompactFheUint16List.encrypt_with_compact_public_key(uint16Array, publicKey);
    return encrypted.serialize();
};
var encrypt32 = function (value, publicKey) {
    var uint32Array = new Uint32Array([value]);
    var encrypted = nodeTfhe.CompactFheUint32List.encrypt_with_compact_public_key(uint32Array, publicKey);
    return encrypted.serialize();
};

var fromHexString = function (hexString) {
    var arr = hexString.match(/.{1,2}/g);
    if (!arr)
        return new Uint8Array();
    return Uint8Array.from(arr.map(function (byte) { return parseInt(byte, 16); }));
};
var toHexString = function (bytes) {
    return bytes.reduce(function (str, byte) { return str + byte.toString(16).padStart(2, '0'); }, '');
};
var bytesToNumber = function (byteArray) {
    var result = 0;
    for (var i = byteArray.length - 1; i >= 0; i--) {
        result = result * 256 + byteArray[i];
    }
    return result;
};
var isAddress = function (address) {
    if (/^(0x)?[0-9a-f]{40}$/i.test(address.toLowerCase())) {
        // check if it has the basic requirements of an address
        return true;
    }
    return false;
};

var generateToken = function (params) { return __awaiter(void 0, void 0, void 0, function () {
    var keypair, msgParams;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, sodium.ready];
            case 1:
                _a.sent();
                keypair = sodium.crypto_box_keypair();
                msgParams = {
                    types: {
                        // This refers to the domain the contract is hosted on.
                        EIP712Domain: [
                            { name: 'name', type: 'string' },
                            { name: 'version', type: 'string' },
                            { name: 'chainId', type: 'uint256' },
                            { name: 'verifyingContract', type: 'address' },
                        ],
                        // Refer to primaryType.
                        Reencrypt: [{ name: 'publicKey', type: 'bytes32' }],
                    },
                    // This defines the message you're proposing the user to sign, is dapp-specific, and contains
                    // anything you want. There are no required fields. Be as explicit as possible when building out
                    // the message schema.
                    // This refers to the keys of the following types object.
                    primaryType: 'Reencrypt',
                    domain: {
                        // Give a user-friendly name to the specific contract you're signing for.
                        name: params.name || 'Authorization token',
                        // This identifies the latest version.
                        version: params.version || '1',
                        // This defines the network, in this case, Mainnet.
                        chainId: params.chainId || 9000,
                        // // Add a verifying contract to make sure you're establishing contracts with the proper entity.
                        verifyingContract: params.verifyingContract,
                    },
                    message: {
                        publicKey: "0x".concat(toHexString(keypair.publicKey)),
                    },
                };
                return [2 /*return*/, {
                        keypair: keypair,
                        token: msgParams,
                    }];
        }
    });
}); };

var decrypt = function (keypair, ciphertext) { return __awaiter(void 0, void 0, void 0, function () {
    var toDecrypt, decrypted;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, sodium.ready];
            case 1:
                _a.sent();
                toDecrypt = typeof ciphertext === 'string' ? fromHexString(ciphertext) : ciphertext;
                decrypted = sodium.crypto_box_seal_open(toDecrypt, keypair.publicKey, keypair.privateKey);
                return [2 /*return*/, bytesToNumber(decrypted)];
        }
    });
}); };

var createInstance = function (params) {
    var chainId = params.chainId, publicKey = params.publicKey, keypairs = params.keypairs;
    var contractKeypairs = {};
    if (keypairs) {
        Object.keys(keypairs).forEach(function (contractAddress) {
            if (isAddress(contractAddress)) {
                var oKeys_1 = Object.keys(keypairs[contractAddress]);
                if (['signature', 'privateKey', 'publicKey'].every(function (v) { return oKeys_1.includes(v); })) {
                    contractKeypairs[contractAddress] = {
                        signature: keypairs[contractAddress].signature,
                        publicKey: fromHexString(keypairs[contractAddress].publicKey),
                        privateKey: fromHexString(keypairs[contractAddress].privateKey),
                    };
                }
            }
        });
    }
    return {
        // Parameters
        encrypt8: function (value) {
            if (!value)
                throw new Error('Missing value');
            if (typeof value !== 'number')
                throw new Error('Value must be a number');
            return encrypt8(value, publicKey);
        },
        encrypt16: function (value) {
            if (!value)
                throw new Error('Missing value');
            if (typeof value !== 'number')
                throw new Error('Value must be a number');
            return encrypt16(value, publicKey);
        },
        encrypt32: function (value) {
            if (!value)
                throw new Error('Missing value');
            if (typeof value !== 'number')
                throw new Error('Value must be a number');
            return encrypt32(value, publicKey);
        },
        // Reencryption
        generateToken: function (options) {
            return __awaiter(this, void 0, void 0, function () {
                var kp, _a, token, keypair;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            if (!options || !options.verifyingContract)
                                throw new Error('Missing contract address');
                            if (!isAddress(options.verifyingContract))
                                throw new Error('Invalid contract address');
                            if (!options.force && contractKeypairs[options.verifyingContract]) {
                                kp = contractKeypairs[options.verifyingContract];
                            }
                            return [4 /*yield*/, generateToken({
                                    verifyingContract: options.verifyingContract,
                                    name: options.name,
                                    version: options.version,
                                    chainId: chainId,
                                    keypair: kp,
                                })];
                        case 1:
                            _a = _b.sent(), token = _a.token, keypair = _a.keypair;
                            contractKeypairs[options.verifyingContract] = {
                                privateKey: keypair.privateKey,
                                publicKey: keypair.publicKey,
                                signature: null,
                            };
                            return [2 /*return*/, { token: token, publicKey: keypair.publicKey }];
                    }
                });
            });
        },
        setTokenSignature: function (contractAddress, signature) {
            if (contractKeypairs[contractAddress] && contractKeypairs[contractAddress].privateKey) {
                contractKeypairs[contractAddress].signature = signature;
            }
        },
        getTokenSignature: function (contractAddress) {
            if (this.hasKeypair(contractAddress)) {
                return {
                    publicKey: contractKeypairs[contractAddress].publicKey,
                    signature: contractKeypairs[contractAddress].signature,
                };
            }
            return null;
        },
        hasKeypair: function (contractAddress) {
            return contractKeypairs[contractAddress] != null && !!contractKeypairs[contractAddress].signature;
        },
        decrypt: function (contractAddress, ciphertext) {
            return __awaiter(this, void 0, void 0, function () {
                var kp;
                return __generator(this, function (_a) {
                    if (!ciphertext)
                        throw new Error('Missing ciphertext');
                    if (!contractAddress)
                        throw new Error('Missing contract address');
                    kp = contractKeypairs[contractAddress];
                    if (!kp)
                        throw new Error("Missing keypair for ".concat(contractAddress));
                    return [2 /*return*/, decrypt(kp, ciphertext)];
                });
            });
        },
        serializeKeypairs: function () {
            var stringKeypairs = {};
            Object.keys(contractKeypairs).forEach(function (contractAddress) {
                var signature = contractKeypairs[contractAddress].signature;
                if (!signature)
                    return;
                stringKeypairs[contractAddress] = {
                    signature: signature,
                    publicKey: toHexString(contractKeypairs[contractAddress].publicKey),
                    privateKey: toHexString(contractKeypairs[contractAddress].privateKey),
                };
            });
            return stringKeypairs;
        },
    };
};

var createTFHEKey = function () {
    var block_params = new nodeTfhe.ShortintParameters(nodeTfhe.ShortintParametersName.PARAM_SMALL_MESSAGE_2_CARRY_2_COMPACT_PK);
    var config = nodeTfhe.TfheConfigBuilder.all_disabled().enable_custom_integers(block_params).build();
    var clientKey = nodeTfhe.TfheClientKey.generate(config);
    var publicKey = nodeTfhe.TfheCompactPublicKey.new(clientKey);
    return { publicKey: publicKey, clientKey: clientKey };
};

exports.createInstance = createInstance;
exports.createTFHEKey = createTFHEKey;

==> fhevmjs-0.0.2.tgz: package/lib/node.js <==
'use strict';

var nodeTfhe = require('node-tfhe');
var sodium = require('libsodium-wrappers');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */


function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var encrypt8 = function (value, publicKey) {
    var uint8Array = new Uint8Array([value]);
    var encrypted = nodeTfhe.CompactFheUint8List.encrypt_with_compact_public_key(uint8Array, publicKey);
    return encrypted.serialize();
};
var encrypt16 = function (value, publicKey) {
    var uint16Array = new Uint16Array([value]);
    var encrypted = nodeTfhe.CompactFheUint16List.encrypt_with_compact_public_key(uint16Array, publicKey);
    return encrypted.serialize();
};
var encrypt32 = function (value, publicKey) {
    var uint32Array = new Uint32Array([value]);
    var encrypted = nodeTfhe.CompactFheUint32List.encrypt_with_compact_public_key(uint32Array, publicKey);
    return encrypted.serialize();
};

var fromHexString = function (hexString) {
    var arr = hexString.replace(/^(0x)/, '').match(/.{1,2}/g);
    if (!arr)
        return new Uint8Array();
    return Uint8Array.from(arr.map(function (byte) { return parseInt(byte, 16); }));
};
var toHexString = function (bytes) {
    return bytes.reduce(function (str, byte) { return str + byte.toString(16).padStart(2, '0'); }, '');
};
var bytesToNumber = function (byteArray) {
    var result = 0;
    for (var i = byteArray.length - 1; i >= 0; i--) {
        result = result * 256 + byteArray[i];
    }
    return result;
};
var isAddress = function (address) {
    if (/^(0x)?[0-9a-f]{40}$/i.test(address.toLowerCase())) {
        // check if it has the basic requirements of an address
        return true;
    }
    return false;
};

var generateToken = function (params) { return __awaiter(void 0, void 0, void 0, function () {
    var keypair, msgParams;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, sodium.ready];
            case 1:
                _a.sent();
                keypair = params.keypair || sodium.crypto_box_keypair();
                msgParams = {
                    types: {
                        // This refers to the domain the contract is hosted on.
                        EIP712Domain: [
                            { name: 'name', type: 'string' },
                            { name: 'version', type: 'string' },
                            { name: 'chainId', type: 'uint256' },
                            { name: 'verifyingContract', type: 'address' },
                        ],
                        // Refer to primaryType.
                        Reencrypt: [{ name: 'publicKey', type: 'bytes32' }],
                    },
                    // This defines the message you're proposing the user to sign, is dapp-specific, and contains
                    // anything you want. There are no required fields. Be as explicit as possible when building out
                    // the message schema.
                    // This refers to the keys of the following types object.
                    primaryType: 'Reencrypt',
                    domain: {
                        // Give a user-friendly name to the specific contract you're signing for.
                        name: params.name || 'Authorization token',
                        // This identifies the latest version.
                        version: params.version || '1',
                        // This defines the network, in this case, Mainnet.
                        chainId: params.chainId || 9000,
                        // // Add a verifying contract to make sure you're establishing contracts with the proper entity.
                        verifyingContract: params.verifyingContract,
                    },
                    message: {
                        publicKey: "0x".concat(toHexString(keypair.publicKey)),
                    },
                };
                return [2 /*return*/, {
                        keypair: {
                            publicKey: keypair.publicKey,
                            privateKey: keypair.privateKey,
                        },
                        token: msgParams,
                    }];
        }
    });
}); };

var decrypt = function (keypair, ciphertext) { return __awaiter(void 0, void 0, void 0, function () {
    var toDecrypt, decrypted;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, sodium.ready];
            case 1:
                _a.sent();
                toDecrypt = typeof ciphertext === 'string' ? fromHexString(ciphertext) : ciphertext;
                decrypted = sodium.crypto_box_seal_open(toDecrypt, keypair.publicKey, keypair.privateKey);
                return [2 /*return*/, bytesToNumber(decrypted)];
        }
    });
}); };

var createInstance = function (params) {
    var chainId = params.chainId, publicKey = params.publicKey, keypairs = params.keypairs;
    var buff = fromHexString(publicKey);
    var tfheCompactPublicKey = nodeTfhe.TfheCompactPublicKey.deserialize(buff);
    var contractKeypairs = {};
    if (keypairs) {
        Object.keys(keypairs).forEach(function (contractAddress) {
            if (isAddress(contractAddress)) {
                var oKeys_1 = Object.keys(keypairs[contractAddress]);
                if (['signature', 'privateKey', 'publicKey'].every(function (v) { return oKeys_1.includes(v); })) {
                    contractKeypairs[contractAddress] = {
                        signature: keypairs[contractAddress].signature,
                        publicKey: fromHexString(keypairs[contractAddress].publicKey),
                        privateKey: fromHexString(keypairs[contractAddress].privateKey),
                    };
                }
            }
        });
    }
    return {
        // Parameters
        encrypt8: function (value) {
            if (!value)
                throw new Error('Missing value');
            if (typeof value !== 'number')
                throw new Error('Value must be a number');
            return encrypt8(value, tfheCompactPublicKey);
        },
        encrypt16: function (value) {
            if (!value)
                throw new Error('Missing value');
            if (typeof value !== 'number')
                throw new Error('Value must be a number');
            return encrypt16(value, tfheCompactPublicKey);
        },
        encrypt32: function (value) {
            if (!value)
                throw new Error('Missing value');
            if (typeof value !== 'number')
                throw new Error('Value must be a number');
            return encrypt32(value, tfheCompactPublicKey);
        },
        // Reencryption
        generateToken: function (options) {
            return __awaiter(this, void 0, void 0, function () {
                var kp, _a, token, keypair;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            if (!options || !options.verifyingContract)
                                throw new Error('Missing contract address');
                            if (!isAddress(options.verifyingContract))
                                throw new Error('Invalid contract address');
                            if (!options.force && contractKeypairs[options.verifyingContract]) {
                                kp = contractKeypairs[options.verifyingContract];
                            }
                            return [4 /*yield*/, generateToken({
                                    verifyingContract: options.verifyingContract,
                                    name: options.name,
                                    version: options.version,
                                    chainId: chainId,
                                    keypair: kp,
                                })];
                        case 1:
                            _a = _b.sent(), token = _a.token, keypair = _a.keypair;
                            contractKeypairs[options.verifyingContract] = {
                                privateKey: keypair.privateKey,
                                publicKey: keypair.publicKey,
                                signature: null,
                            };
                            return [2 /*return*/, { token: token, publicKey: keypair.publicKey }];
                    }
                });
            });
        },
        setTokenSignature: function (contractAddress, signature) {
            if (contractKeypairs[contractAddress] && contractKeypairs[contractAddress].privateKey) {
                contractKeypairs[contractAddress].signature = signature;
            }
        },
        getTokenSignature: function (contractAddress) {
            if (this.hasKeypair(contractAddress)) {
                return {
                    publicKey: contractKeypairs[contractAddress].publicKey,
                    signature: contractKeypairs[contractAddress].signature,
                };
            }
            return null;
        },
        hasKeypair: function (contractAddress) {
            return contractKeypairs[contractAddress] != null && !!contractKeypairs[contractAddress].signature;
        },
        decrypt: function (contractAddress, ciphertext) {
            return __awaiter(this, void 0, void 0, function () {
                var kp;
                return __generator(this, function (_a) {
                    if (!ciphertext)
                        throw new Error('Missing ciphertext');
                    if (!contractAddress)
                        throw new Error('Missing contract address');
                    kp = contractKeypairs[contractAddress];
                    if (!kp)
                        throw new Error("Missing keypair for ".concat(contractAddress));
                    return [2 /*return*/, decrypt(kp, ciphertext)];
                });
            });
        },
        serializeKeypairs: function () {
            var stringKeypairs = {};
            Object.keys(contractKeypairs).forEach(function (contractAddress) {
                var signature = contractKeypairs[contractAddress].signature;
                if (!signature)
                    return;
                stringKeypairs[contractAddress] = {
                    signature: signature,
                    publicKey: toHexString(contractKeypairs[contractAddress].publicKey),
                    privateKey: toHexString(contractKeypairs[contractAddress].privateKey),
                };
            });
            return stringKeypairs;
        },
    };
};

var createTfheKeypair = function () {
    var block_params = new nodeTfhe.ShortintParameters(nodeTfhe.ShortintParametersName.PARAM_SMALL_MESSAGE_2_CARRY_2_COMPACT_PK);
    var config = nodeTfhe.TfheConfigBuilder.all_disabled().enable_custom_integers(block_params).build();
    var clientKey = nodeTfhe.TfheClientKey.generate(config);
    var publicKey = nodeTfhe.TfheCompactPublicKey.new(clientKey);
    publicKey = nodeTfhe.TfheCompactPublicKey.deserialize(publicKey.serialize());
    return { clientKey: clientKey, publicKey: publicKey };
};
var createTfhePublicKey = function () {
    var publicKey = createTfheKeypair().publicKey;
    return toHexString(publicKey.serialize());
};

exports.createInstance = createInstance;
exports.createTfheKeypair = createTfheKeypair;
exports.createTfhePublicKey = createTfhePublicKey;
